collect_and_atoms

Function collect_and_atoms 

fn collect_and_atoms(expr: &PartitionExpr, out: &mut Vec<PartitionExpr>) -> bool
Flattens an expression into atomic terms when it is a pure conjunction tree.

Returns false if any OR is encountered, signaling caller to skip this simplification path.