fn is_atomic_range_expr(expr: &PartitionExpr) -> boolExpand description
Returns whether expr is an atomic column op value range predicate.
Supported operators are limited to <, <=, >, and >=.
fn is_atomic_range_expr(expr: &PartitionExpr) -> boolReturns whether expr is an atomic column op value range predicate.
Supported operators are limited to <, <=, >, and >=.